pub trait Transport {
// Required method
fn send(&self, config: &Client, request: RequestParts) -> Result<Raw>;
}Expand description
Defines the behavior required from a transport participant in the transport workflow.
pub trait Transport {
// Required method
fn send(&self, config: &Client, request: RequestParts) -> Result<Raw>;
}Defines the behavior required from a transport participant in the transport workflow.